@@ -18,7 +18,6 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkdds.endpoint import endpoint_data
 
 class CreateDBInstanceRequest(RpcRequest):
 
@@ -26,11 +25,6 @@ class CreateDBInstanceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'CreateDBInstance','dds')
 		self.set_method('POST')
 
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
@@ -56,6 +50,11 @@ class CreateDBInstanceRequest(RpcRequest):
 
 	def set_NetworkType(self, NetworkType):  # String
 		self.add_query_param('NetworkType', NetworkType)
+	def get_StorageType(self): # String
+		return self.get_query_params().get('StorageType')
+
+	def set_StorageType(self, StorageType):  # String
+		self.add_query_param('StorageType', StorageType)
 	def get_ResourceGroupId(self): # String
 		return self.get_query_params().get('ResourceGroupId')
 
