@@ -18,7 +18,6 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkdds.endpoint import endpoint_data
 
 class CreateServerlessDBInstanceRequest(RpcRequest):
 
@@ -26,11 +25,6 @@ class CreateServerlessDBInstanceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'CreateServerlessDBInstance','dds')
 		self.set_method('POST')
 
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 	def get_CapacityUnit(self): # String
 		return self.get_query_params().get('CapacityUnit')
 
